@@ -88,6 +88,9 @@ sub new {
             # PLACEHOLDER
             } elsif ($i =~ /^-placeholder/) {
                 # check if placeholder contains special regex characters
+                if (not defined $data{$i}) {
+                    confess "ERROR NBI::Seq: Placeholder cannot be empty\n";
+                }
                 if ($data{$i} =~ /[\*\+\?]/) {
                     confess "ERROR NBI::Seq: Placeholder cannot contain special regex characters\n";
                 }
@@ -353,7 +356,7 @@ NBI::Opts - A class for representing a the SLURM options for NBI::Slurm
 
 =head1 VERSION
 
-version 0.9.0
+version 0.12.0
 
 =head1 SYNOPSIS
 
@@ -564,7 +567,7 @@ Andrea Telatin <proch@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2023 by Andrea Telatin.
+This software is Copyright (c) 2023-2025 by Andrea Telatin.
 
 This is free software, licensed under:
 
