@@ -7,8 +7,8 @@ use NBI::Job;
 use NBI::Opts;
 use base qw(Exporter);
 our @ISA = qw(Exporter);
-our @EXPORT = qw(Job Opts load_config has_queue %FORMAT_STRINGS);
-$NBI::Slurm::VERSION = '0.8.7';
+our @EXPORT = qw(Job Opts load_config has_queue timelog %FORMAT_STRINGS);
+$NBI::Slurm::VERSION = '0.12.0';
 
 
 
@@ -71,8 +71,12 @@ sub has_squeue {
 sub queues {
   my $can_fail = shift;
   # Retrieve queues from SLURM
-  my $has_sinfo = `sinfo --version`;
-  chomp($has_sinfo);
+  my $has_sinfo = undef;
+  eval {
+    $has_sinfo = `sinfo --version > /dev/null 2>&1`;
+  };
+  
+  chomp($has_sinfo) if defined $has_sinfo;
   if (not defined $has_sinfo and ! $can_fail) {
     Carp::croak "ERROR NBI::Slurm: sinfo failed. Are you in a SLURM cluster?\n";
   }
@@ -135,6 +139,18 @@ sub days_since_update {
     return $days_since_update;
 }
 
+sub timelog {
+    my $tag = shift;
+    $tag = "nbi-slurm" unless defined $tag;
+    my ($sec, $min, $hour, $day, $month, $year) = localtime(time);
+    $year += 1900;  # Adjust year (localtime returns years since 1900)
+    $month += 1;    # Adjust month (localtime returns 0-11)
+    
+    # Format with leading zeros
+    return sprintf("[%s:%04d-%02d-%02d %02d:%02d:%02d]\t", 
+            $tag, $year, $month, $day, $hour, $min, $sec);
+}
+
 1;
 
 __END__
@@ -149,7 +165,7 @@ NBI::Slurm - NBI Slurm module
 
 =head1 VERSION
 
-version 0.8.7
+version 0.12.0
 
 =head1 SYNOPSIS
 
@@ -250,6 +266,16 @@ The C<NBI::Slurm> package includes the following classes:
 
 =back
 
+=head1 FUNCTIONS
+
+The C<NBI::Slurm> package provides the following functions:
+
+=over 4
+
+=item * B<timelog(str)>: Generate a timestamp for logging purposes, with an optional tag (string)
+
+=back
+
 Please refer to the documentation for each class for more information on their methods and usage.
 
 =head1 AUTHOR
@@ -258,7 +284,7 @@ Andrea Telatin <proch@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2023 by Andrea Telatin.
+This software is Copyright (c) 2023-2025 by Andrea Telatin.
 
 This is free software, licensed under:
 
